.. _scenario_core:

Core
====

.. doxygenclass:: scenario::core::World
   :members:

.. doxygenclass:: scenario::core::Model
   :members:

.. doxygenclass:: scenario::core::Link
   :members:

.. doxygenclass:: scenario::core::Joint
   :members:

.. doxygenenum:: scenario::core::JointControlMode

.. doxygenfile:: core/utils/utils.h
   :project: scenario